==> taxonomy_entity_index-8.x-1.18.tar.gz: taxonomy_entity_index/src/Plugin/views/argument/TaxonomyEntityIndexDepth.php <==
<?php

declare(strict_types=1);

namespace Drupal\taxonomy_entity_index\Plugin\views\argument;

use Drupal\Component\Utility\DeprecationHelper;
use Drupal\Core\Database\Connection;
use Drupal\Core\Database\Query\Condition;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\taxonomy\Plugin\views\argument\IndexTidDepth;
use Drupal\views\Plugin\views\display\DisplayPluginBase;
use Drupal\views\ViewExecutable;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Abstract argument handler for entity taxonomy terms with depth.
 *
 * @ingroup views_argument_handlers
 * @phpstan-consistent-constructor
 */
abstract class TaxonomyEntityIndexDepth extends IndexTidDepth {

  /**
   * Stores the base table information.
   *
   * @var array
   */
  private $baseTableInfo = [];

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, EntityStorageInterface $termStorage, protected Connection $database, protected EntityStorageInterface|EntityRepositoryInterface $entityRepository) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $termStorage);
    DeprecationHelper::backwardsCompatibleCall(
      \Drupal::VERSION,
      '10.3',
      fn () => parent::__construct($configuration, $plugin_id, $plugin_definition, $this->entityRepository),
      fn () => parent::__construct($configuration, $plugin_id, $plugin_definition, $termStorage)
    );
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager')->getStorage('taxonomy_term'),
      $container->get('database'),
      $container->get('entity.repository')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function init(ViewExecutable $view, DisplayPluginBase $display, array &$options = NULL) {
    parent::init($view, $display, $options);
    $this->baseTableInfo = $this->viewsData->get($this->table);
  }

  /**
   * {@inheritdoc}
   */
  public function query($group_by = FALSE) {
    $this->ensureMyTable();
    if (!empty($this->options['break_phrase']) && (static::breakString($this->argument)->value === [-1])) {
      return FALSE;
    }

    [$operator, $ids] = $this->getOperatorAndIds();
    if (!$tids = $this->convertIdsToEntityIds($ids)) {
      $tids = [-1];
    }

    // Now build the subqueries.
    $subquery = $this->database->select('taxonomy_entity_index', 'tn');

    $base_field = $this->baseTableInfo['taxonomy_entity_index_entity_tid']['relationship']['base field'];
    $real_field = $this->baseTableInfo['taxonomy_entity_index_entity_tid']['relationship']['real field'];

    $subquery->addField('tn', $base_field);

    if (isset($this->baseTableInfo['table']['entity type'])) {
      $subquery->condition('entity_type', $this->baseTableInfo['table']['entity type']);
    }

    $or = new Condition('OR');
    $where = $or->condition('tn.tid', $tids, $operator);
    $last = "tn";

    if ($this->options['depth'] > 0) {
      $subquery->leftJoin('taxonomy_term__parent', 'th', "th.entity_id = tn.tid");
      $last = "th";
      foreach (range(1, abs((int) $this->options['depth'])) as $count) {
        $subquery->leftJoin('taxonomy_term__parent', "th$count", "$last.parent_target_id = th$count.entity_id");
        $where->condition("th$count.entity_id", $tids, $operator);
        $last = "th$count";
      }
    }
    elseif ($this->options['depth'] < 0) {
      foreach (range(1, abs((int) $this->options['depth'])) as $count) {
        $subquery->leftJoin('taxonomy_term__parent', "th$count", "$last.entity_id = th$count.parent_target_id");
        $where->condition("th$count.entity_id", $tids, $operator);
        $last = "th$count";
      }
    }

    $subquery->condition($where);

    $this->query->addWhere(0, "$this->tableAlias.$real_field", $subquery, 'IN');
  }

  /**
   * Fetches the operator and the list of IDs.
   *
   * @return array
   *   The first item is the operator and second is the list of IDs.
   */
  protected function getOperatorAndIds() {
    $results = [];

    if (!empty($this->options['break_phrase'])) {
      $break = static::breakString($this->argument);
      $results[] = (count($break->value) > 1) ? 'IN' : '=';
      $results[] = $break->value;
    }
    else {
      $results[] = "=";
      $results[] = $this->argument;
    }

    return $results;
  }

  /**
   * Converts the provided IDs to taxonomy term entity IDs.
   *
   * @param mixed $ids
   *   Either the list of provided IDs or a single item.
   *
   * @return array
   *   The list of taxonomy term entity IDs.
   */
  abstract protected function convertIdsToEntityIds($ids);

}

==> taxonomy_entity_index-8.x-1.19.tar.gz: taxonomy_entity_index/src/Plugin/views/argument/TaxonomyEntityIndexDepth.php <==
<?php

declare(strict_types=1);

namespace Drupal\taxonomy_entity_index\Plugin\views\argument;

use Drupal\Core\Database\Connection;
use Drupal\Core\Database\Query\Condition;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\taxonomy\Plugin\views\argument\IndexTidDepth;
use Drupal\views\Plugin\views\display\DisplayPluginBase;
use Drupal\views\ViewExecutable;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Abstract argument handler for entity taxonomy terms with depth.
 *
 * @ingroup views_argument_handlers
 * @phpstan-consistent-constructor
 */
abstract class TaxonomyEntityIndexDepth extends IndexTidDepth {

  /**
   * Stores the base table information.
   *
   * @var array
   */
  private $baseTableInfo = [];

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, protected Connection $database, protected EntityRepositoryInterface $entityRepository) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $this->entityRepository);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('database'),
      $container->get('entity.repository')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function init(ViewExecutable $view, DisplayPluginBase $display, ?array &$options = NULL) {
    parent::init($view, $display, $options);
    $this->baseTableInfo = $this->viewsData->get($this->table);
  }

  /**
   * {@inheritdoc}
   */
  public function query($group_by = FALSE) {
    $this->ensureMyTable();
    if (!empty($this->options['break_phrase']) && (static::breakString($this->argument)->value === [-1])) {
      return FALSE;
    }

    [, $ids] = $this->getOperatorAndIds();
    if (!$tids = $this->convertIdsToEntityIds($ids)) {
      $tids = [-1];
    }

    // Now build the subqueries.
    $subquery = $this->database->select('taxonomy_entity_index', 'tn');

    $base_field = $this->baseTableInfo['taxonomy_entity_index_entity_tid']['relationship']['base field'];
    $real_field = $this->baseTableInfo['taxonomy_entity_index_entity_tid']['relationship']['real field'];

    $subquery->addField('tn', $base_field);

    if (isset($this->baseTableInfo['table']['entity type'])) {
      $subquery->condition('entity_type', $this->baseTableInfo['table']['entity type']);
    }

    $or = new Condition('OR');
    $where = $or->condition('tn.tid', $tids, 'IN');
    $last = "tn";

    if ($this->options['depth'] > 0) {
      $subquery->leftJoin('taxonomy_term__parent', 'th', "th.entity_id = tn.tid");
      $last = "th";
      foreach (range(1, abs((int) $this->options['depth'])) as $count) {
        $subquery->leftJoin('taxonomy_term__parent', "th$count", "$last.parent_target_id = th$count.entity_id");
        $where->condition("th$count.entity_id", $tids, 'IN');
        $last = "th$count";
      }
    }
    elseif ($this->options['depth'] < 0) {
      foreach (range(1, abs((int) $this->options['depth'])) as $count) {
        $subquery->leftJoin('taxonomy_term__parent', "th$count", "$last.entity_id = th$count.parent_target_id");
        $where->condition("th$count.entity_id", $tids, 'IN');
        $last = "th$count";
      }
    }

    $subquery->condition($where);

    $this->query->addWhere(0, "$this->tableAlias.$real_field", $subquery, 'IN');
  }

  /**
   * Fetches the operator and the list of IDs.
   *
   * @return array
   *   The first item is the operator and second is the list of IDs.
   */
  protected function getOperatorAndIds() {
    $results = [];

    if (!empty($this->options['break_phrase'])) {
      $break = static::breakString($this->argument);
      $results[] = (count($break->value) > 1) ? 'IN' : '=';
      $results[] = $break->value;
    }
    else {
      $results[] = "=";
      $results[] = $this->argument;
    }

    return $results;
  }

  /**
   * Converts the provided IDs to taxonomy term entity IDs.
   *
   * @param mixed $ids
   *   Either the list of provided IDs or a single item.
   *
   * @return array
   *   The list of taxonomy term entity IDs.
   */
  abstract protected function convertIdsToEntityIds($ids);

}
